@@ -13,9 +13,9 @@
  *
  *  You should have received a copy of the GNU Lesser General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: GeckoPrintService.h 6588 2006-09-13 11:34:25Z chpe $
+ *  $Id$
  */
 
 #ifndef GECKO_PRINT_SERVICE_H
@@ -23,6 +23,7 @@
 
 #include <gtk/gtkpagesetup.h>
 #include <gtk/gtkprintsettings.h>
+#include <gtk/gtkprinter.h>
 
 #include <nsIPrintingPromptService.h>
 
@@ -44,7 +45,7 @@ public:
 	GeckoPrintService();
 	virtual ~GeckoPrintService();
 
-	static nsresult TranslateSettings (GtkPrintSettings*, GtkPageSetup *, const nsACString&, PRBool, nsIPrintSettings*);
+	static nsresult TranslateSettings (GtkPrintSettings*, GtkPageSetup *, GtkPrinter *, const nsACString&, PRInt16, PRBool, nsIPrintSettings*);
 
 private:
 	nsresult PrintUnattended (nsIDOMWindow *, nsIPrintSettings *);
